@@ -1,3 +1,3 @@
 """Init File for weatherbit."""
-from weatherbitpypi.client import Api
+from weatherbitpypi.client import Weatherbit
 from weatherbitpypi.errors import WeatherbitError
\ No newline at end of file
