@@ -78,6 +78,7 @@ class Weatherbit:
                 "station": row["station"],
                 "ob_time": row["ob_time"],
                 "datetime": row["datetime"],
+                "ts": row["ts"],
                 "temp": row["temp"],
                 "city_name": row["city_name"],
                 "app_temp": row["app_temp"],
@@ -121,6 +122,7 @@ class Weatherbit:
                 "city_name": city_name,
                 "timezone": timezone,
                 "valid_date": row["valid_date"],
+                "ts": row["ts"],
                 "temp": row["temp"],
                 "max_temp": row["max_temp"],
                 "min_temp": row["min_temp"],
@@ -174,7 +176,7 @@ class Weatherbit:
             items.append(WeatherAlerts(item))
             return items
         else:
-            for row in json_data["data"]:
+            for row in json_data["alerts"]:
                 item = {
                     "city_name": city_name,
                     "timezone": timezone,
@@ -184,7 +186,7 @@ class Weatherbit:
                     "effective_local": row["effective_local"],
                     "expires_local": row["expires_local"],
                     "uri": row["uri"],
-                    "regions": [],
+                    "regions": row["regions"],
                 }
                 items.append(WeatherAlerts(item))
             return items
